==> opennms-services-1.6.7-sources.jar: org/opennms/netmgt/linkd/scheduler/ReadyRunnable.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.                                                            
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//       
// For more information contact: 
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.netmgt.linkd.scheduler;

/**
 * This interface extends the {@link java.lang.Runnable runnable}interface and
 * provides a method to determine if the runnable is ready to start.
 * 
 * @author <a href="mailto:antonio@opennms.org">Antonio Russo</a>
 * @author <a href="mailto:weave@oculan.com">Brian Weaver </a>
 * @author <a href="http://www.opennms.org">OpenNMS.org </a>
 * 
 */
public interface ReadyRunnable extends Runnable {
    /**
     * Returns true if the runnable is ready to start.
     * 
     */
    public boolean isReady();

    public void suspend();
    
    public boolean isSuspended();
    
    public void wakeUp();
    
    public void unschedule();
    
    public void schedule();
        
    public boolean equals(ReadyRunnable runnable);

    public String getInfo();
    
    public String getPackageName();
    
    public void setPackageName(String pkg);

    
}

==> opennms-services-1.8.12-sources.jar: org/opennms/netmgt/linkd/scheduler/ReadyRunnable.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.                                                            
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//       
// For more information contact: 
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.netmgt.linkd.scheduler;

/**
 * This interface extends the {@link java.lang.Runnable runnable}interface and
 * provides a method to determine if the runnable is ready to start.
 *
 * @author <a href="mailto:antonio@opennms.org">Antonio Russo</a>
 */
public interface ReadyRunnable extends Runnable {
    /**
     * Returns true if the runnable is ready to start.
     *
     * @return a boolean.
     */
    public boolean isReady();

    /**
     * <p>suspend</p>
     */
    public void suspend();
    
    /**
     * <p>isSuspended</p>
     *
     * @return a boolean.
     */
    public boolean isSuspended();
    
    /**
     * <p>wakeUp</p>
     */
    public void wakeUp();
    
    /**
     * <p>unschedule</p>
     */
    public void unschedule();
    
    /**
     * <p>schedule</p>
     */
    public void schedule();
        
    /**
     * <p>equals</p>
     *
     * @param runnable a {@link org.opennms.netmgt.linkd.scheduler.ReadyRunnable} object.
     * @return a boolean.
     */
    public boolean equals(ReadyRunnable runnable);

    /**
     * <p>getInfo</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getInfo();
    
    /**
     * <p>getPackageName</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getPackageName();
    
    /**
     * <p>setPackageName</p>
     *
     * @param pkg a {@link java.lang.String} object.
     */
    public void setPackageName(String pkg);

    
}
